==> qiho-center-api-2.7.25-hrd-20201224.085106-20-sources.jar: com/qiho/center/api/enums/ShotOrder/ShotOrderConstant.java <==
package com.qiho.center.api.enums.ShotOrder;

/**
 * Created by danke on 2017/6/21.
 * 踢单辅助相关的常量配置,增加action对应的key在这里添加
 */
public class ShotOrderConstant {

    private ShotOrderConstant(){

    }

    public static class StrategyAction{

        private StrategyAction(){

        }

        /**
         * 24小时累计下单校验action的key
         */
        public static final String REPEAT_PLACE_ORDER = "repeat_place_order";
        /**
         * 详细地址长度的action
         */
        public static final String ADRESS_LENGTH = "adress_length";
        /**
         * 重复下单action的key
         */
        public static final String REPEAT_CHECK = "repeat_check";

        /**
         * 下单手机号action的key
         */
        public static final String ORDER_MOBILE = "order_mobile";

        /** 24小时同一手机号商品action的key */
        public static final String COUNT_PHONT_ITEM = "ct-phone-item";
        /**
         * 地址无效
         */
        public static final String INVALID_ADDRESS = "invalid_address";


        /** 24小时同一手机号商家action的key */
        public static final String COUNT_PHONE_MERCHANT = "ct-phone-merchant";

        /** IP归属地手机号归属地收货地址校验 */
        public static final String IP_MOBILE_ADDRESS_CHECK = "ip-mobile-address-check";

        /** 24小时同一推啊用户id下单量校验action的key */
        public static final String REPEAT_ORDER_TUIACID = "repeat_order_tuiacid";

        /** 手机号多次命中现有规则 action 的 key  */
        public static final String MOBILE_DUPLICATE_HIT = "mobile-duplicate-hit";

        /**
         * 收获地址不在指定范围内的key
         */
        public static final String DELIVERY_REGION_EXCLUSIVE = "delivery-region";

        /** 24小时下单量(身份证号统计) action的key */
        public static final String ID_CARD_COUNT = "count-idCard";

        /** 24小时下单量(同一身份证，同一商品) action的key */
        public static final String ID_CARD_ITEM = "ct-idCard-item";

        /** 24小时下单量(同一身份证，同一店铺) action的key */
        public static final String ID_CARD_MERCHANT = "ct-idCard-merchant";
    }
}

==> qiho-center-api-2.8.9-hrd-20210406.062441-1-sources.jar: com/qiho/center/api/enums/ShotOrder/ShotOrderConstant.java <==
package com.qiho.center.api.enums.ShotOrder;

/**
 * Created by danke on 2017/6/21.
 * 踢单辅助相关的常量配置,增加action对应的key在这里添加
 */
public class ShotOrderConstant {

    private ShotOrderConstant(){

    }

    public static class StrategyAction{

        private StrategyAction(){

        }

        /**
         * 24小时累计下单校验action的key
         */
        public static final String REPEAT_PLACE_ORDER = "repeat_place_order";
        /**
         * 详细地址长度的action
         */
        public static final String ADRESS_LENGTH = "adress_length";
        /**
         * 重复下单action的key
         */
        public static final String REPEAT_CHECK = "repeat_check";

        /**
         * 下单手机号action的key
         */
        public static final String ORDER_MOBILE = "order_mobile";

        /** 24小时同一手机号商品action的key */
        public static final String COUNT_PHONT_ITEM = "ct-phone-item";
        /**
         * 地址无效
         */
        public static final String INVALID_ADDRESS = "invalid_address";


        /** 24小时同一手机号商家action的key */
        public static final String COUNT_PHONE_MERCHANT = "ct-phone-merchant";

        /** IP归属地手机号归属地收货地址校验 */
        public static final String IP_MOBILE_ADDRESS_CHECK = "ip-mobile-address-check";

        /** 24小时同一推啊用户id下单量校验action的key */
        public static final String REPEAT_ORDER_TUIACID = "repeat_order_tuiacid";

        /** 手机号多次命中现有规则 action 的 key  */
        public static final String MOBILE_DUPLICATE_HIT = "mobile-duplicate-hit";

        /**
         * 收获地址不在指定范围内的key
         */
        public static final String DELIVERY_REGION_EXCLUSIVE = "delivery-region";

        /** 24小时下单量(身份证号统计) action的key */
        public static final String ID_CARD_COUNT = "count-idCard";

        /** 24小时下单量(同一身份证，同一商品) action的key */
        public static final String ID_CARD_ITEM = "ct-idCard-item";

        /** 24小时下单量(同一身份证，同一店铺) action的key */
        public static final String ID_CARD_MERCHANT = "ct-idCard-merchant";

        /** 六律-身份证号名字*/
        public static final String ID_CARD_NAME = "name-idCard";

        /*** 六律-手机号下单资格*/
        public static final String MOBILE_QUALIFICATION = "mobile-order-qualification";

        /** 开速姓名身份证号匹配*/
        public static final String KAISU_ID_CARD_NAME = "kaisu-name-idCard";

        /*** 六律流量包办理校验*/
        public static final String MOBILE_FLOW_PACKET_CALIBRATION = "ll-flow-packet-calibration";

        /** 作业帮超卖规则*/
        public static final String ZUOYEBANG_OVERSOLD = "zuoyebang-oversold";
    }
}
